"""
This is how hyou use this function
"""

import os

def addition(NUMBER1,NUMBER2):
"""
This is how hyou use this function
"""
    print(NUMBER1 + NUMBER2)



def multiplication(NUMBER1,NUMBER2):

"""
This is how hyou use this function
"""
    print(NUMBER1 * NUMBER2)

def filechecker(FILENAME):
    FILENAME = os.path.isfile(FILENAME)
    print("file exists")